@@ -3,9 +3,8 @@ from django.contrib.admin.widgets import AdminTextareaWidget
 
 
 class MarkupTextarea(forms.widgets.Textarea):
-
     def render(self, name, value, attrs=None, renderer=None):
-        if hasattr(value, 'raw'):
+        if hasattr(value, "raw"):
             value = value.raw
         return super(MarkupTextarea, self).render(name, value, attrs, renderer=renderer)
 
